Plot
------------

.. warning::
    This module is mainly intended for interactive usage, it is experimental and still in development. The API might change without warning and breaks code.


Utilities to plot functions. These are simple helpers to plot functions, they are not meant to be a full-fledged
plotting library.

The plotting is based on ``matplotlib`` and integrates closely with it.

To use the functions more easily, you can use ``pdf.plot.plotpdf(...)``.

.. autosummary::
    :toctree: _generated/plot

    zfit.plot.plot_model_pdfV1
    zfit.plot.plot_sumpdf_components_pdfV1
